# pysvl
## _PySVL Python Space Vehicle Library_


[![Build Status](https://travis-ci.org/joemccann/dillinger.svg?branch=master)](https://github.com/InfinityScienceWorks/pysvl/)

PySVL is a python library for space vehicles, rockets and satellite for their designing, calculating their path, their orbit and more

- fast
- powerfun
- ✨Magic ✨

## Features

- has realtime module
- has database fo other rockets ilke pslv
- visualize and calculate realtime
- calculate with accuracy
- and much more (see the docs)



## more on

docs *docs will be available soon*
[github](https://github.com/InfinityScienceWorks/pysvl/)
## Installation

dependencies :

```sh
numpy
matplotlib
```

For production environments...

```sh
pip install pysvl
```


## Development
version ```1.0.0```
it is at it's initial developement stage






